EndpointDoc class
Full, human-readable documentation for a single API operation.
Constructors
Properties
- description → String
-
Longer explanation.
final
- example → String?
-
A copy-pasteable usage example.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
HTTP method, e.g.
POST.final - name → String
-
SDK method name, e.g.
chat.final -
parameters
→ List<
FieldDoc> -
Query/path parameters.
final
- path → String
-
Request path, e.g.
conversation.final -
requestBody
→ List<
FieldDoc> -
Request body fields.
final
-
response
→ List<
FieldDoc> -
Notable response fields.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String
-
One-line summary.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
) → String - Renders the documentation as a readable multi-line block.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited